"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const match_pattern_1 = require("./match-pattern");
describe('isMatchDirPatternItem', () => {
    describe('item is matched', () => {
        it('exact match', () => {
            const res = match_pattern_1.isMatchDirPatternItem('bar', 'bar');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(1);
        });
        it('pattern is part of dir', () => {
            const res = match_pattern_1.isMatchDirPatternItem('bar/foo', 'bar');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(1);
        });
        it('specificity is larger than 1', () => {
            const res = match_pattern_1.isMatchDirPatternItem('bar/foo/baz', 'bar/foo');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(2);
        });
    });
    describe('item is not matched', () => {
        it('simple unmatch', () => {
            const res = match_pattern_1.isMatchDirPatternItem('abc', 'def');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('same suffix only', () => {
            const res = match_pattern_1.isMatchDirPatternItem('bar/foo', 'bzr/bar/foo');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('dir is part of pattern item', () => {
            const res = match_pattern_1.isMatchDirPatternItem('bar', 'bar/foo');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
    });
});
describe('isMatchNamespacePatternItem', () => {
    describe('item is matched', () => {
        it('exact match', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar', '{bar}');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(1);
        });
        it('pattern is part of name and ends with *', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo', '{bar/*}');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(1.1);
        });
        it('pattern is part of name and ends with * and name has more parts', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo/baz', '{bar/*}');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(1.1);
        });
        it('specificity is larger than 1', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo/baz', '{bar/foo/*}');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(2.2);
        });
        it('multiple *', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo/baz/goo', '{bar/*/baz/*}');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(2.4);
        });
    });
    describe('item is not matched', () => {
        it('simple unmatch', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('abc', '{def}');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('name is part of pattern item', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar', '{bar/foo}');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('pattern is part of name but not ends with *', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo', '{bar}');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('diff in the middle', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo/baz', '{bar/goo/baz}');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
        it('same suffix only', () => {
            const res = match_pattern_1.isMatchNamespacePatternItem('bar/foo', '{bzr/bar/foo}');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.specificity).to.equal(-1);
        });
    });
});
describe('isMatchPatternItem', () => {
    describe('match all', () => {
        it('using match all pattern', () => {
            const res = match_pattern_1.isMatchPatternItem('bar', 'name', match_pattern_1.MATCH_ALL_ITEM);
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.specificity).to.equal(0);
        });
    });
});
describe('isMatchPattern', () => {
    describe('no matches at all', () => {
        it('should return match false with maxSpecificity as -1', () => {
            const res = match_pattern_1.isMatchPattern('bar', 'name', 'foo, baz');
            chai_1.expect(res.match).to.be.false;
            chai_1.expect(res.maxSpecificity).to.equal(-1);
        });
    });
    describe('match one dir item', () => {
        it('should return match true with the correct maxSpecificity', () => {
            const res = match_pattern_1.isMatchPattern('bar/foo/baz', 'name', 'foo, bar/foo , baz');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.maxSpecificity).to.equal(2);
        });
    });
    describe('match more than one dir item', () => {
        it('should return match true with the correct maxSpecificity', () => {
            const res = match_pattern_1.isMatchPattern('bar/foo/baz', 'name', 'bar/foo, bar/foo/baz , baz, bar');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.maxSpecificity).to.equal(3);
        });
    });
    describe('match more than one namespace item', () => {
        it('should return match true with the correct maxSpecificity', () => {
            const res = match_pattern_1.isMatchPattern('bar/foo/baz', 'namespace1/namespace2/name', '{namespace1/namespace2/name}, {namespace1/namespace2/*} , baz, bar');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.maxSpecificity).to.equal(3);
        });
    });
    describe('match more than one namespace item and more than one dir item', () => {
        it('should return match true with the correct maxSpecificity', () => {
            const res = match_pattern_1.isMatchPattern('bar/foo/baz/goo', 'namespace1/namespace2/name', '{namespace1/namespace2/name}, {namespace1/namespace2/*} , bar/foo, bar/foo/baz/goo , baz, bar');
            chai_1.expect(res.match).to.be.true;
            chai_1.expect(res.maxSpecificity).to.equal(4);
        });
    });
});
describe('sortMatchesBySpecificity', () => {
    describe('descending sort', () => {
        it('should descending sort matches by specificity', () => {
            const match1 = {
                specificity: 5,
                config: {},
            };
            const match2 = {
                specificity: 3,
                config: {},
            };
            const match3 = {
                specificity: 7,
                config: {},
            };
            const matches = [match1, match2, match3];
            const res = match_pattern_1.sortMatchesBySpecificity(matches);
            chai_1.expect(res[0].specificity).to.equal(7);
            chai_1.expect(res[1].specificity).to.equal(5);
            chai_1.expect(res[2].specificity).to.equal(3);
        });
    });
});
//# sourceMappingURL=match-pattern.spec.js.map